@@ -9,14 +9,11 @@ from __future__ import absolute_import
 
 import click
 
-from hangman import controller
+from . import controller
 
 
 @click.command()
 def cli():
-    """
-    Start a new game.
-    """
     controller.run()
 
 
